pub struct CardanoBlockClient { /* private fields */ }Available on crate feature
unstable only.Expand description
HTTP client for CardanoBlocksAPI from the aggregator
Implementations
Sourceimpl CardanoBlockClient
impl CardanoBlockClient
Sourcepub fn new(aggregator_requester: Arc<dyn CardanoBlockAggregatorRequest>) -> Self
pub fn new(aggregator_requester: Arc<dyn CardanoBlockAggregatorRequest>) -> Self
Constructs a new CardanoBlockClient.
Sourcepub async fn get_proof<T: ToString>(
&self,
blocks_hashes: &[T],
) -> MithrilResult<CardanoBlocksProofs>
pub async fn get_proof<T: ToString>( &self, blocks_hashes: &[T], ) -> MithrilResult<CardanoBlocksProofs>
Get proofs that the given subset of blocks is included in the Cardano blocks set.
Sourcepub async fn list_snapshots(
&self,
) -> MithrilResult<Vec<CardanoBlocksTransactionsSnapshotListItem>>
pub async fn list_snapshots( &self, ) -> MithrilResult<Vec<CardanoBlocksTransactionsSnapshotListItem>>
Fetch a list of signed Cardano transaction snapshots.
Sourcepub async fn get_snapshot(
&self,
hash: &str,
) -> MithrilResult<Option<CardanoBlocksTransactionsSnapshot>>
pub async fn get_snapshot( &self, hash: &str, ) -> MithrilResult<Option<CardanoBlocksTransactionsSnapshot>>
Get the given Cardano Blocks transaction snapshot data. If it cannot be found, a None is returned.