pub enum VerifyProofsV2Error {
InvalidSetProof {
subject: &'static str,
hashes: Vec<String>,
source: Error,
},
NoCertifiedItem(&'static str),
MalformedData(&'static str, Error),
}Available on crate feature
unstable only.Expand description
Error encountered or produced by the verification of a set of proofs.
Variants
InvalidSetProof
The verification of an individual crate::messages::MkSetProofMessagePart failed.
Fields
NoCertifiedItem(&'static str)
No certified items to verify in the set proof
MalformedData(&'static str, Error)
An individual crate::messages::MkSetProofMessagePart could not be converted to a crate::entities::MkSetProof for verification.