pub struct CardanoBlocksProofs {
pub certificate_hash: String,
pub certified_blocks: Option<MkSetProofMessagePart<CardanoBlockMessagePart>>,
pub non_certified_blocks: Vec<String>,
pub latest_block_number: BlockNumber,
pub security_parameter: BlockNumberOffset,
}unstable only.Expand description
A cryptographic proof for a set of Cardano blocks
Fields
certificate_hash: StringHash of the certificate that validates this proof Merkle root
certified_blocks: Option<MkSetProofMessagePart<CardanoBlockMessagePart>>Blocks that have been certified
non_certified_blocks: Vec<String>Hashes of the blocks that could not be certified
latest_block_number: BlockNumberLatest block number that has been certified by the associated Mithril certificate
security_parameter: BlockNumberOffsetSecurity parameter that has been certified by the associated Mithril certificate
Implementations
Sourceimpl CardanoBlocksProofsMessage
impl CardanoBlocksProofsMessage
Sourcepub fn blocks_hashes(&self) -> Vec<String>
pub fn blocks_hashes(&self) -> Vec<String>
Hashes of the Cardano blocks that have been certified
Sourceimpl CardanoBlocksProofsMessage
impl CardanoBlocksProofsMessage
Sourcepub fn new(
certificate_hash: &str,
certified_blocks: Option<MkSetProofMessagePart<CardanoBlockMessagePart>>,
non_certified_blocks: Vec<String>,
latest_block_number: BlockNumber,
security_parameter: BlockNumberOffset,
) -> CardanoBlocksProofsMessage
pub fn new( certificate_hash: &str, certified_blocks: Option<MkSetProofMessagePart<CardanoBlockMessagePart>>, non_certified_blocks: Vec<String>, latest_block_number: BlockNumber, security_parameter: BlockNumberOffset, ) -> CardanoBlocksProofsMessage
Create a new ProofsV2CardanoBlocksMessage
Sourcepub fn verify(&self) -> Result<VerifiedCardanoBlocks, VerifyProofsV2Error>
pub fn verify(&self) -> Result<VerifiedCardanoBlocks, VerifyProofsV2Error>
Verify that all the certified blocks proofs are valid
The following checks will be executed:
1 - Check that each Merkle proof is valid
2 - Check that all proofs share the same Merkle root
3 - Assert that there’s at least one certified block
If every check is okay, the hex encoded Merkle root of the proof will be returned.