pub struct CardanoBlocksTransactionsSnapshotListItem {
pub merkle_root: String,
pub epoch: Epoch,
pub block_number_signed: BlockNumber,
pub block_number_tip: BlockNumber,
pub hash: String,
pub certificate_hash: String,
pub created_at: DateTime<Utc>,
}Available on crate feature
unstable only.Expand description
Message structure of a Cardano Transactions Snapshot list item
Fields
merkle_root: StringMerkle root of the Cardano Blocks and Transactions snapshot
epoch: EpochEpoch of the Cardano Blocks and Transactions snapshot
block_number_signed: BlockNumberThe maximum block number signed in the Cardano Blocks and Transactions snapshot
block_number_tip: BlockNumberThe block number of the tip of the chain at snapshot time of the Cardano Blocks and Transactions
hash: StringHash of the Cardano Blocks and Transactions snapshot
certificate_hash: StringHash of the associated certificate
created_at: DateTime<Utc>Time of creation