CardanoTransactionsProofsV2

Struct CardanoTransactionsProofsV2 

pub struct CardanoTransactionsProofsV2 {
    pub certificate_hash: String,
    pub certified_transactions: Option<MkSetProofMessagePart<CardanoTransactionMessagePart>>,
    pub non_certified_transactions: Vec<String>,
    pub latest_block_number: BlockNumber,
    pub security_parameter: BlockNumberOffset,
}
Available on crate feature unstable only.
A cryptographic proof for a set of Cardano transactions

Fields

certificate_hash: String

Hash of the certificate that validates this proof Merkle root

certified_transactions: Option<MkSetProofMessagePart<CardanoTransactionMessagePart>>

Transactions that have been certified

non_certified_transactions: Vec<String>

Hashes of the transactions that could not be certified

latest_block_number: BlockNumber

Latest block number that has been certified by the associated Mithril certificate

security_parameter: BlockNumberOffset

Security parameter that has been certified by the associated Mithril certificate

Implementations

Source

impl CardanoTransactionsProofsV2Message

pub fn transactions_hashes(&self) -> Vec<String>

Hashes of the Cardano transactions that have been certified

Source

impl CardanoTransactionsProofsV2Message

pub fn new( certificate_hash: &str, certified_transactions: Option<MkSetProofMessagePart<CardanoTransactionMessagePart>>, non_certified_transactions: Vec<String>, latest_block_number: BlockNumber, security_parameter: BlockNumberOffset, ) -> CardanoTransactionsProofsV2Message

Create a new ProofsV2CardanoTransactionsMessage

pub fn verify( &self, ) -> Result<VerifiedCardanoTransactionsV2, VerifyProofsV2Error>

Verify that all the certified transactions proofs are valid

The following checks will be executed:

1 - Check that each Merkle proof is valid

2 - Check that all proofs share the same Merkle root

3 - Assert that there’s at least one certified transaction

If every check is okay, the hex encoded Merkle root of the proof will be returned.