pub struct VerifiedCardanoBlocks { /* private fields */ }Available on crate feature
unstable only.Expand description
Blocks successfully verified by CardanoBlocksProofsMessage::verify.
Can be used to reconstruct a ProtocolMessage
and confirm it was signed by a certificate.
Implementations
Sourceimpl VerifiedCardanoBlocks
impl VerifiedCardanoBlocks
Sourcepub fn certificate_hash(&self) -> &str
pub fn certificate_hash(&self) -> &str
Hash of the certificate that signs this struct Merkle root.
Sourcepub fn certified_merkle_root(&self) -> &str
pub fn certified_merkle_root(&self) -> &str
Hex encoded Merkle root of the certified blocks
Sourcepub fn certified_blocks(&self) -> &[CardanoBlockMessagePart]
pub fn certified_blocks(&self) -> &[CardanoBlockMessagePart]
Certified blocks
Sourcepub fn certified_blocks_hashes(&self) -> Vec<String>
pub fn certified_blocks_hashes(&self) -> Vec<String>
Hashes of the certified blocks
Sourcepub fn latest_certified_block_number(&self) -> BlockNumber
pub fn latest_certified_block_number(&self) -> BlockNumber
Latest block number that has been certified by the associated Mithril certificate
Sourcepub fn security_parameter(&self) -> BlockNumberOffset
pub fn security_parameter(&self) -> BlockNumberOffset
Security parameter that has been certified by the associated Mithril certificate